---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Please provide some minimal code to reproduce the issue. If at all possible, use a Python environment with only the `kiara` and `kiara_modules.core` packages installed, as this will make it easier to transform this issue into a unit test.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment, versions (please complete the following information):**
 - OS: [e.g. iOS]
 - Python: [e.g. 3.9.1]
 - Versions of relevant packages (`kiara`, `kiara_modules.core`, etc.)
 - Python environment used (e.g. system, conda, ...)

**Additional context**
Add any other context about the problem here.
